colorprint
=====
A Python package for color-print on terminal.

Example
-------
```python
>> import dyeprint as dp
>> foo = dp.ColorSheet('red', 'yellow', 'bold')
>> print(foo.dye('hello world'))
```
![](./pic/dyeprint.gif)


Installing
--------
```sh
[sudo] pip install dyeprint
```
